#!/bin/bash

# Paths with command params.
STATS_COLLECTOR_CMD="/opt/aspera/shares/u/stats-collector/bin/aspera-stats-collector \
  -wait 10 \
  -procname aspera-stats-collector \
  -cp /opt/aspera/shares/u/stats-collector/lib/stats-collector-2.0.0.142.jar:/opt/aspera/shares/u/stats-collector/lib/castify-common-1.0.8.jar:/opt/aspera/shares/u/stats-collector/lib/castify-common-1.0.8-testing.jar:/opt/aspera/shares/u/stats-collector/lib/protect-1.0.0.jar:/opt/aspera/shares/u/stats-collector/lib/logback-classic-1.0.11.jar:/opt/aspera/shares/u/stats-collector/lib/logback-core-1.0.11.jar:/opt/aspera/shares/u/stats-collector/lib/jul-to-slf4j-1.7.5.jar:/opt/aspera/shares/u/stats-collector/lib/jcl-over-slf4j-1.7.5.jar:/opt/aspera/shares/u/stats-collector/lib/HikariCP-2.4.7.jar:/opt/aspera/shares/u/stats-collector/lib/slf4j-api-1.7.21.jar:/opt/aspera/shares/u/stats-collector/lib/commons-daemon-1.0.10.jar:/opt/aspera/shares/u/stats-collector/lib/commons-lang-2.6.jar:/opt/aspera/shares/u/stats-collector/lib/commons-httpclient-3.1.jar:/opt/aspera/shares/u/stats-collector/lib/commons-codec-1.6.jar:/opt/aspera/shares/u/stats-collector/lib/guice-3.0.jar:/opt/aspera/shares/u/stats-collector/lib/guava-15.0.jar:/opt/aspera/shares/u/stats-collector/lib/snakeyaml-1.11.jar:/opt/aspera/shares/u/stats-collector/lib/mariadb-java-client-1.4.6.jar:/opt/aspera/shares/u/stats-collector/lib/jackson-mapper-asl-1.9.13.jar:/opt/aspera/shares/u/stats-collector/lib/jackson-core-asl-1.9.13.jar:/opt/aspera/shares/u/stats-collector/lib/jcommander-1.30.jar:/opt/aspera/shares/u/stats-collector/lib/commons-logging-1.0.4.jar:/opt/aspera/shares/u/stats-collector/lib/javax.inject-1.jar:/opt/aspera/shares/u/stats-collector/lib/aopalliance-1.0.jar:/opt/aspera/shares/u/stats-collector/lib/cglib-2.2.1-v20090111.jar:/opt/aspera/shares/u/stats-collector/lib/asm-3.1.jar \
  -Xmx64M \
  -Xms8M \
  -Dlogback.configurationFile=/opt/aspera/shares/u/stats-collector/etc/logback-apps.xml \
  -Dinstallation.dir=/opt/aspera/shares/u/stats-collector \
  -Xss2m \
  -Dstatscollector.log.dir=/opt/aspera/shares/u/stats-collector/var/log/stats-collector \
  -XX:ErrorFile=/opt/aspera/shares/u/stats-collector/var/log/stats-collector/java_error_%p.log \
  com.aspera.statscollector.StatsCollectorDaemon"

PID_FILE="/opt/aspera/shares/u/stats-collector/var/run/aspera/stats-collector/aspera-stats-collector.pid"
LOG_FILE="/opt/aspera/shares/u/stats-collector/var/log/stats-collector/aspera-stats-collector_start.log"

start() {
    echo "Starting stats-collector..."
    if [ -f $PID_FILE ] && kill -0 $(cat $PID_FILE) > /dev/null 2>&1; then
        echo "Stats-collector is already running."
    else
        nohup $STATS_COLLECTOR_CMD > $LOG_FILE 2>&1 &
        echo $! > $PID_FILE
        echo "Stats-collector started with PID $(cat $PID_FILE)."
    fi
}


stop() {
    echo "Stopping stats-collector..."
    PIDS=$(ps -ef | awk '/aspera-stats-collector/ && !/awk/ {print $2}')

    if [ -n "$PIDS" ]; then
        echo "$PIDS" | xargs kill -9
        rm -f $PID_FILE
        echo "Stats-collector stopped."
    else
        echo "Stats-collector is not running."
    fi
}

restart() {
    echo "Restarting stats-collector..."
    stop
    sleep 3 
    start
}

status() {
    echo "Checking status of stats-collector..."
    # Get the list of PIDs
    PIDS=$(ps -ef | awk '/aspera-stats-collector/ && !/awk/ {print $2}')

    if [ -n "$PIDS" ]; then
        echo "Stats-collector is running with PIDs: $PIDS."
    else
        echo "Stats-collector is not running."
    fi
}

case "$1" in
    start)
        start
        ;;
    stop)
        stop
        ;;
    restart)
        restart
        ;;
    status)
        status
        ;;
    *)
        echo "Usage: $0 {start|stop|restart|status}"
        exit 1
        ;;
esac

exit 0