@echo off
rem 
rem  Service installation and control script for @SERVICE_DISPLAY_NAME@
rem
rem  @SERVICE_DESCRIPTION@
rem
rem  (c) Aspera Inc.
rem 

@echo off

setlocal

set EXEC_PATH=%~dp0
CALL :RESOLVE "%EXEC_PATH%\s\..\.." INSTALL_DIR
 
rem -- Service description
set SERVICE_DESCRIPTION=@SERVICE_DESCRIPTION@
 
rem -- Service name
set SERVICE_NAME=@SERVICE_NAME@

rem -- Service Display name
set SERVICE_DISPLAY_NAME=@SERVICE_DISPLAY_NAME@

rem -- Procrun
set PROCRUN_EXE=%EXEC_PATH%aspera-stats-collector.exe
 
rem -- Service CLASSPATH
set SERVICE_CLASSPATH=@CPATH@
 
rem -- Service main class
set MAIN_SERVICE_CLASS=@SERVICE_MAIN_CLASS@

rem -- Service start method (--StartMethod)
set MAIN_SERVICE_START_METHOD=windowsServiceStart

set MAIN_SERVICE_STOP_METHOD=windowsServiceStop

rem -- Service start arguments (--StartParams=%MAIN_SERVICE_START_ARGS%)
set MAIN_SERVICE_START_ARGS=

set MAIN_SERVICE_STOP_ARGS=

rem -- The prefix of log files
set LOG_PREFIX=service

rem -- Path for log files
set LOG_PATH=%INSTALL_DIR%\logs

rem -- STDERR log file
set ERR_LOG_FILE=%LOG_PATH%\stderr.txt

rem -- STDOUT log file
set OUT_LOG_FILE=%LOG_PATH%\stdout.txt

rem -- Startup mode (manual or auto)
set SERVICE_STARTUP=auto

set JAVA_HOME=%INSTALL_DIR%\jre
set JVM_PATH=%JAVA_HOME%\bin\client\jvm.dll

rem -- Use server VM if available
if exist "%JAVA_HOME%\bin\server\jvm.dll" set JVM_PATH=%JAVA_HOME%\bin\server\jvm.dll

rem ---------------------------------------------------------------------------
set SERVICE_OPTIONS=^
 --LogLevel=Info^
 --DisplayName="%SERVICE_DISPLAY_NAME%"^
 --Description="%SERVICE_DESCRIPTION%"^
 --Jvm="%JVM_PATH%"^
 --Classpath="%SERVICE_CLASSPATH%"^
 --StartMode=jvm^
 --StartClass=%MAIN_SERVICE_CLASS%^
 --StartMethod=%MAIN_SERVICE_START_METHOD%^
 --StopMode=jvm^
 --StopClass=%MAIN_SERVICE_CLASS%^
 --StopMethod=%MAIN_SERVICE_STOP_METHOD%^
 --StopParams="%MAIN_SERVICE_STOP_ARGS%"^
 --LogPrefix="%LOG_PREFIX%"^
 --LogPath="%LOG_PATH%"^
 --StdOutput="%OUT_LOG_FILE%"^
 --StdError="%ERR_LOG_FILE%"^
 --Startup=%SERVICE_STARTUP%^
 ++JvmOptions="-Xmx64M"^
 ++JvmOptions="-Xms8M"^
 ++JvmOptions="-XX:ErrorFile=%LOG_PATH%\java_error_%p.log"^
 ++JvmOptions="-Dlogback.configurationFile=%INSTALL_DIR%\etc\logback.xml"^
 ++JvmOptions="-Dstatscollector.log.dir=%LOG_PATH%"^
 ++JvmOptions="-Dinstallation.dir=%INSTALL_DIR%"^
 ++JvmOptions="-Dinstallation.type=standalone"
set RESTART=0
 
:GETOPTS
if /I "%1" == "start" ( goto START )
if /I "%1" == "stop" ( goto STOP )
if /I "%1" == "help" ( goto HELP )
if /I "%1" == "restart" ( goto RESTART )
if /I "%1" == "install" ( goto INSTALL )
if /I "%1" == "remove" ( goto REMOVE )
if /I "%1" == "admin" ( goto ADMIN )
goto HELP
 
rem -- START ------------------------------------------------------------------
:START
 
echo Starting service %SERVICE_NAME%...
net start "%SERVICE_NAME%"
goto FIN

rem -- INSTALL ----------------------------------------------------------------
:INSTALL
 
echo Installing service %SERVICE_NAME%...
"%PROCRUN_EXE%" install "%SERVICE_NAME%" %SERVICE_OPTIONS% --StartParams="%MAIN_SERVICE_START_ARGS%"
call :PRINT_STATUS %ERRORLEVEL% Installation
sc config "%SERVICE_NAME%" binPath= "\"%EXEC_PATH%aspera-stats-collector.exe\" \"//RS//%SERVICE_NAME%\"" 
sc failure "%SERVICE_NAME%" reset= 0 actions= restart/60000/restart/60000/restart/60000 

IF not "%3" == "" ( sc config "%SERVICE_NAME%" obj= "%2" password= "%3" )

goto FIN
 
rem -- STOP -------------------------------------------------------------------
:STOP
 
echo Stopping service %SERVICE_NAME%...
net stop "%SERVICE_NAME%"
if "%RESTART%" == "1" ( goto START )
goto FIN
 
rem -- REMOVE -----------------------------------------------------------------
:REMOVE
 
echo Removing service %SERVICE_NAME%...
"%PROCRUN_EXE%" delete "%SERVICE_NAME%" %SERVICE_OPTIONS%
call :PRINT_STATUS %ERRORLEVEL% Removal
goto FIN

rem -- ADMIN ----------------------------------------------------------------
:ADMIN

shift
IF not "%1" == "" (
  IF not "%1" == "-y" (
    IF "%MAIN_SERVICE_START_ARGS%" == "" (
      set MAIN_SERVICE_START_ARGS=%1
    ) ELSE (
      set MAIN_SERVICE_START_ARGS=%MAIN_SERVICE_START_ARGS%;%1
    )
  )
  shift
  GOTO :ADMIN
)

if "%0" == "-y" (
  echo Y| "%JAVA_HOME%\bin\java.exe" -cp "%SERVICE_CLASSPATH%" -Xmx64M -Xms8M "-Dlogback.configurationFile=%INSTALL_DIR%\etc\logback-apps.xml" "-Dstatscollector.log.dir=%LOG_PATH%" "-Dinstallation.dir=%INSTALL_DIR%" "@ADMIN_MAIN_CLASS@" "%MAIN_SERVICE_START_ARGS%"
) else (
  "%JAVA_HOME%\bin\java.exe" -cp "%SERVICE_CLASSPATH%" -Xmx64M -Xms8M "-Dlogback.configurationFile=%INSTALL_DIR%\etc\logback-apps.xml" "-Dstatscollector.log.dir=%LOG_PATH%" "-Dinstallation.dir=%INSTALL_DIR%" "@ADMIN_MAIN_CLASS@" "%MAIN_SERVICE_START_ARGS%"
)

goto FIN
 
rem -- RESTART ----------------------------------------------------------------
:RESTART
set RESTART=1
goto STOP
 
rem -- HELP -------------------------------------------------------------------
:HELP
 
echo+
echo Usage: %~n0 install^|remove^|start^|stop^|restart^|admin
echo+
echo install      install the %SERVICE_NAME% service
echo remove       remove the %SERVICE_NAME% service
echo start        start the %SERVICE_NAME% service
echo stop         stop the %SERVICE_NAME% service
echo restart      restart the %SERVICE_NAME% service
echo admin        run the admin tool
goto FIN


:RESOLVE
SET %2=%~f1
GOTO:EOF

:PRINT_STATUS
IF %1 EQU 0 (
  echo %~2 completed.
) ELSE (
  echo %~2 failed with exit code %1. Check "%LOG_PATH%\%LOG_PREFIX%.DATE.log" for details.
)
GOTO:EOF

:FIN
endlocal